@@ -1,7 +1,7 @@
 /**
  * Application configuration values
 
- * Copyright (C) 2008  Sylvain Beucler
+ * Copyright (C) 2008, 2009  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -136,8 +136,18 @@ void Config::Update()
 static wxString FindDefaultDinkrefDir()
 {
 #if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__
-  const wxString fallback_woe_dir = _T("C:/Program Files/Dink Smallwood");
+  const wxString fallback_woe_dir = _T("C:/Program Files/FreeDink");
 
+  /* Just check in the same directory */
+  char exe_dir[MAX_PATH];
+  if (GetModuleFileName(NULL, exe_dir, sizeof(exe_dir)) < 0)
+    return fallback_woe_dir;
+  wxString str = exe_dir;
+  return IOUtils::GetParentDir(str);
+
+  /* The rest is too complex and error-prone when there's more than
+     one Dink version installed, let's just skip */
+if (false) {
   //
   // First see if it's in the registry.
   //
@@ -247,6 +257,7 @@ static wxString FindDefaultDinkrefDir()
   // We shouldn't get here, but we'll try and save the program.
   f_In.close();
   return strBuf;
+}
 
 # else /* !WIN32 */
 
