@@ -2,7 +2,7 @@
  * DFArc main frame
 
  * Copyright (C) 2005, 2006  Dan Walma
- * Copyright (C) 2008  Sylvain Beucler
+ * Copyright (C) 2008, 2010  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -129,7 +129,7 @@ void DFArcFrame::OnAbout(wxCommandEvent& aCommandEvent)
     "DFArc version %s\n"
     "Copyright (C) 2004  Andrew Reading (merlin)\n"
     "Copyright (C) 2005, 2006  Dan Walma (redink1)\n"
-    "Copyright (C) 2008  Sylvain Beucler (Beuc)\n"
+    "Copyright (C) 2008, 2009, 2010  Sylvain Beucler (Beuc)\n"
     "Build Date: %s\n"
     "Powered by bzip2 (http://www.bzip.org) and wxWidgets (http://www.wxwidgets.org)"),
 				  version.c_str(), __TDATE__);
@@ -513,12 +513,11 @@ void DFArcFrame::showIntroductionText(wxCommandEvent& aEvent)
 {
   ::wxMessageBox(_("Welcome to DFArc, the Dink Smallwood front end!\n"
 "\n"
-"You can choose to play the original game, Dink Smallwood, or"
-" Dink-Modules (D-Mods) which contain new adventures.  After completing"
-" the main game, give the included D-Mod (Mystery Island) a try.\n"
+"You can choose to play the original game (Dink Smallwood) or"
+" Dink-Modules (D-Mods) which contain new adventures.\n"
 "\n"
-"There are hundreds of free D-Mods available, just click File-Download"
-" D-Mods."),
+"After completing the main game, give some D-Mods a try.\n"
+"There are hundreds of them, just click File-Download D-Mods."),
 		 _("Introduction"),
 		 wxOK | wxICON_INFORMATION, this);
   return;
